/*
 * Copyright (C) 1999 AntennaHouse Inc.  All Rights Reserved
 */

/*----------------------------------
   TITLE:STREAM_OEM.H
   PRODUCT:DMC Product
   Comment:DMC Interface
   ------------------------------------*/
/*
 * Author:Zhu YaoBing
 *
 * 1999/09/01 First Release
 */
 

#ifndef _STREAM_OEM_H_
#define _STREAM_OEM_H_

#include "text_oem.h"
#include <iostream>
#include <fstream>

using namespace std;

#ifdef __cplusplus
extern "C" {            /* Assume C declarations for C++ */
#endif  /* __cplusplus */


DMC_TXIF_EXPORT INT  DMC_GetTextStream_V5(Byte* Appfile, ostream* pOutStream, DMC_TEXTINFO_V5* TextInfo, DMC_OLEERR_CALLBACK pFuncOleErr);
DMC_TXIF_EXPORT INT  DMC_GetPageTextStream_V5(Byte* Appfile, ostream* pOutStream, DMC_TEXTINFO_V5* TextInfo, int* Pages, DMC_OLEERR_CALLBACK pFuncOleErr);
#ifdef DMC_WIN
DMC_TXIF_EXPORT INT  DMC_GetTextStream_V5W(Word* Appfile, ostream* pOutStream, DMC_TEXTINFO_V5* TextInfo, DMC_OLEERR_CALLBACK pFuncOleErr);
DMC_TXIF_EXPORT INT  DMC_GetPageTextStream_V5W(Word* Appfile, ostream* pOutStream, DMC_TEXTINFO_V5* TextInfo, int* Pages, DMC_OLEERR_CALLBACK pFuncOleErr);
#endif
DMC_TXIF_EXPORT INT  DMC_GetTextStream_V4(Byte* Appfile, ostream* pOutStream, DMC_TEXTINFO_V4* TextInfo, DMC_OLEERR_CALLBACK pFuncOleErr);
DMC_TXIF_EXPORT INT  DMC_GetPageTextStream_V4(Byte* Appfile, ostream* pOutStream, DMC_TEXTINFO_V4* TextInfo, int* Pages, DMC_OLEERR_CALLBACK pFuncOleErr);//quman 041213

#ifdef __cplusplus
}
#endif  /* __cplusplus */


#endif/* _TEXT_OEM_H_ */

